<?php

/**
 * InterWorx Hosting Control Panel
 *
 * <pre>
 * +----------------------------------------------------------------------+
 * | Copyright (c) 2000-2010 InterWorx L.L.C., All Rights Reserved.       |
 * +----------------------------------------------------------------------+
 * | Redistribution and use in source form, with or without modification  |
 * | is NOT permitted without consent from the copyright holder.          |
 * |                                                                      |
 * | THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS "AS IS" AND |
 * | ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,    |
 * | THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A          |
 * | PARTICULAR PURPOSE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,    |
 * | EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,  |
 * | PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR   |
 * | PROFITS; OF BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY  |
 * | OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT         |
 * | (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE    |
 * | USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH     |
 * | DAMAGE.                                                              |
 * +----------------------------------------------------------------------+
 * </pre>
 *
 * @package InterWorx
 * @author  Malin Lorch <mlorch@liquidweb.com>
 * @date    Aug 12, 2020
 */

/**
 * @package Interworx
 * @subpackage Plugin_Acronis
 */
class Model_Backups_Backups extends Model_Acronis
{
    const BACKUP_ID = 'backupId';
    const CREATED = 'created';
    const DATE = 'date';
    const ARCHIVE_ID = 'archiveId';
    const VAULT_ID  = 'vaultId';
    const MACHINE_ID = 'machineId';
    const LEGACY_ID = 'legacyId';
    const TENANT_AGENT_ID = 'tenantAgentId';


    private $_instanceId;



    /**
     * @param string $instanceId
     */
    public function __construct($instanceId)
    {
        $this->_instanceId = $instanceId;
    }

    /**
     * Get backups.
     *
     * @return array
     */
    public function getBackups()
    {
        $backups = $this->_getBackupsFromApi();
        $this->_getCache()->cacheBackups($backups);

        return $backups;
    }

    /**
     * Get backups from api.
     *
     * @return array
     */
    private function _getBackupsFromApi()
    {
        $backups = $this->_getApi()->getBackups($this->_instanceId);
        $result = array();

        foreach ($backups as $backup) {
            $date = $this->_formatDate($backup['created']);

            $backupId = $backup['backup_id'];
            $legacyId = $backup['legacy_id'];
            $archive = $backup['archive'];

            $vaultId = $archive['vault_id'];
            $archiveId = $archive['id'];
            $machineId = $archive['agent_id'];

            $backupDetails = array(
                self::DATE => $date,
                self::BACKUP_ID => $backupId,
                self::LEGACY_ID => $legacyId,
                self::VAULT_ID => $vaultId,
                self::ARCHIVE_ID => $archiveId,
                self::MACHINE_ID => $machineId,
                self::CREATED => $backup['created'],
                self::TENANT_AGENT_ID => $backup['tenant_id']
            );

            $result[] = $backupDetails;

            $this->_cacheDetails($backupDetails);
        }

        return $result;
    }

    /**
     * cache machine id, legacy id, createdAt, and tenant agent id.
     *
     * @param array $backupDetails
     */
    private function _cacheDetails(array $backupDetails)
    {
        $Cache = $this->_getCache();

        $machineId = $backupDetails[self::MACHINE_ID];
        $legacyId = $backupDetails[self::LEGACY_ID];
        $tenantAgentId = $backupDetails[self::TENANT_AGENT_ID];
        $backupId = $backupDetails[self::BACKUP_ID];
        $createdAt = $backupDetails[self::CREATED];

        $Cache->cacheMachineId($machineId);
        $Cache->cacheLegacyId($backupId, $legacyId);
        $Cache->cacheTenantAgentId($tenantAgentId);
        $Cache->cacheBackupCreatedAt($backupId, $createdAt);
    }
}
