<?php
/**
 * InterWorx Hosting Control Panel
 *
 * <pre>
 * +----------------------------------------------------------------------+
 * | Copyright (c) 2000-2010 InterWorx L.L.C., All Rights Reserved.       |
 * +----------------------------------------------------------------------+
 * | Redistribution and use in source form, with or without modification  |
 * | is NOT permitted without consent from the copyright holder.          |
 * |                                                                      |
 * | THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS "AS IS" AND |
 * | ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,    |
 * | THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A          |
 * | PARTICULAR PURPOSE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,    |
 * | EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,  |
 * | PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR   |
 * | PROFITS; OF BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY  |
 * | OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT         |
 * | (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE    |
 * | USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH     |
 * | DAMAGE.                                                              |
 * +----------------------------------------------------------------------+
 * </pre>
 *
 * @package InterWorx
 * @author  Malin Lorch <mlorch@liquidweb.com>
 * @date    Aug 17, 2020
 */

/**
 *
 * @package Interworx
 * @subpackage Plugin_Acronis
 */
class Model_Recovery_Files_Siteworx extends Model_Recovery_Files
{
    /**
     * Get root content for sw user.
     *
     * @return array
     */
    public function getRootContent()
    {
        $rootPath = $this->_getRootPath();
        $rootContent = $this->_getDirContentByPath($rootPath);

        return $this->_filterVarFromContent($rootContent);
    }

    /**
     * Get sw root path.
     *
     * @return string
     */
    private function _getRootPath()
    {
        return IW::SW()->getPackageRoot();
    }

    /**
     * filter sw root content - should exclude var.
     *
     * @param array $content
     * @return array
     */
    private function _filterVarFromContent(array $content)
    {
        $filtered = array_filter($content, function ($dir) {
            return $dir['name'] !== 'var';
        });

        return array_values($filtered);
    }

    /**
     * Get sw alt location path.
     *
     * @param Siteworx $SW
     * @return string
     */
    public static function getRestoreAltLocationPath(Siteworx $SW)
    {
        $root = $SW->getPackageRoot();
        $recoveryDir = self::RECOVERY_DIR_NAME;
        return "$root/$recoveryDir";
    }

    /**
     * @param string $path
     * @return array
     */
    public function getDirectoryContent($path)
    {
        $root = $this->_getRootPath();
        $dirPath = ltrim($path, '/');
        return $this->_getDirContentByPath("$root/$dirPath");
    }

    /**
     * @param array   $paths
     * @param boolean $deleteNewerFiles
     */
    public function recoverDirectories(array $paths, $deleteNewerFiles = false)
    {
        $absolutePaths = $this->_getAbsolutePaths($paths);
        $Dirs = $this->_getDirsWithLocalPathIndex($absolutePaths);

        $this->_recoverDirectories($Dirs, $deleteNewerFiles);
    }

    /**
     * @param array $paths
     */
    public function restoreToAltLocation(array $paths)
    {
        $absolutePaths = $this->_getAbsolutePaths($paths);
        $Dirs = $this->_getDirsWithLocalPathIndex($absolutePaths);

        $ids = $this->_getDirIds($Dirs);
        $this->_restoreToAltLocation($ids);
    }

    /**
     * @param array $paths
     * @return array
     */
    private function _getAbsolutePaths(array $paths)
    {
        return array_map(function ($path) {
            return $this->_getAbsolutePath($path);
        }, $paths);
    }

    /**
     * Get absolute path.
     * Expects $path to be relative to sw root.
     *
     * @param string $path
     * @return string
     */
    private function _getAbsolutePath($path)
    {
        $root = $this->_getRootPath();
        $dirPath = ltrim($path, '/');
        return "$root/$dirPath";
    }


    /**
     * @param array $dirIds
     */
    private function _restoreToAltLocation(array $dirIds)
    {
        $newDirName = date("Y-m-d-H-i-s");
        $path = self::getRestoreAltLocationPath(IW::SW()) . "/$newDirName/";
        $this->_createRestoreAltLocationDir($path);

        $legacyId = $this->getLegacyId();
        $tenantAgentId = $this->getAgentTenantId();
        $this->_getApi()->recoverDirectoriesToAltLocation($legacyId, $tenantAgentId, $dirIds, $path);
    }
}
