<?php
/**
 * InterWorx Hosting Control Panel
 *
 * <pre>
 * +----------------------------------------------------------------------+
 * | Copyright (c) 2000-2010 InterWorx L.L.C., All Rights Reserved.       |
 * +----------------------------------------------------------------------+
 * | Redistribution and use in source form, with or without modification  |
 * | is NOT permitted without consent from the copyright holder.          |
 * |                                                                      |
 * | THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS "AS IS" AND |
 * | ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,    |
 * | THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A          |
 * | PARTICULAR PURPOSE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,    |
 * | EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,  |
 * | PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR   |
 * | PROFITS; OF BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY  |
 * | OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT         |
 * | (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE    |
 * | USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH     |
 * | DAMAGE.                                                              |
 * +----------------------------------------------------------------------+
 * </pre>
 *
 * @package InterWorx
 * @author  Malin Lorch <mlorch@liquidweb.com>
 * @date    Jan 12, 2021
 */

/**
 * @package InterWorx
 * @subpackage Plugin
 */
class Model_Recovery_Plans extends Model_Acronis
{
    /**
     * @return array
     */
    public function getAll()
    {
        $apiRes = $this->_getApi()->getAllRecoveryPlans();
        $plans = $this->_formatPlans($apiRes);

        return $plans;
    }

    /**
     * @param array $apiRes
     * @return array
     */
    private function _formatPlans(array $apiRes)
    {
        $plans = array();

        foreach ($apiRes as $plan) {
            $plans[] = array(
                'recoveryId' => $plan['uuid'],
                'planId' => $plan['policy']['id'],
                'state' => $plan['state']
            );
        }

        return $plans;
    }

    /**
     * resume recovery.
     *
     * @param string $uuid
     */
    public function resumeRecovery($uuid)
    {
        $this->_validatePlan($uuid);
        $this->_getApi()->ignoreErrorsAndResumeRecovery($uuid);
    }

    /**
     * @param string $uuid
     */
    private function _validatePlan($uuid)
    {
        $plan = $this->_getExistingPlan($uuid);
        $state = $plan['state'];

        if ($state !== 'paused') {
            throw new Exception_ResumeRecovery($state);
        }
    }

    /**
     * Gets list of plans from acronis api and returns plan with matching uuid.
     * Throws exception if no plan with matching uuid exists.
     *
     * @param string $uuid
     * @return array
     */
    private function _getExistingPlan($uuid)
    {
        $plans = $this->getAll();

        foreach ($plans as $plan) {
            if ($plan['recoveryId'] === $uuid) {
                return $plan;
            }
        }

        throw new Exception_InvalidInput($uuid);
    }
}
